@@ -1,7 +1,7 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 use Rope::Object;
 my (%META, %PRO);
 our @ISA;
@@ -392,9 +392,11 @@ BEGIN {
 						$build->{properties}->{$_}->{value} = ref $builder ? $builder->($build) : $caller->$builder($build);
 					}
 				}
+				$self->INITIALISE($build) if $self->can('INITIALISE');
 				tie %{${$self}->{prototype}}, 'Rope::Object', $PRO{scope}($caller, $self, %{$build});
 				$META{initialised}{$caller}->{${$self}->{identifier}} = $self;
 				$self->{ROPE_init}->();
+				$self->INITIALISED() if $self->can('INITIALISED');
 				return $self;
 			};
 		}
@@ -496,7 +498,6 @@ sub from_data {
 	return $pkg->new($meta)->new();
 }
 
-
 sub from_nested_array {
 	my ($pkg, $data, $meta) = @_;
 
@@ -574,7 +575,9 @@ sub set_meta {
 	$PRO{requires}($name)(ref $meta->{requires} eq 'ARRAY' ? @{$meta->{requires}} : keys %{$meta->{requires}}) if ($meta->{requires});
 	$PRO{extends}($name)(@{$meta->{extends}}) if ($meta->{extends});
 	$PRO{with}($name)(@{$meta->{with}}) if ($meta->{with});
-	$PRO{properties}($name)(ref $meta->{properties} eq 'ARRAY' ? @{$meta->{properties}} : %{$meta->{properties}}) if ($meta->{properties})
+	$PRO{properties}($name)(ref $meta->{properties} eq 'ARRAY' ? @{$meta->{properties}} : %{$meta->{properties}}) if ($meta->{properties});
+	$PRO{keyword}($name, 'INITIALISE', $meta->{INITIALISE}) if $meta->{INITIALISE};
+	$PRO{keyword}($name, 'INITIALISED', $meta->{INITIALISED}) if $meta->{INITIALISED};
 }
 
 sub clear_meta {
@@ -603,7 +606,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.27
+Version 0.28
 
 =cut
 
@@ -618,7 +621,6 @@ Version 0.27
 		loops => 1,
 		hitches => 10,
 		...
-
 	);
 
 	properties (
@@ -658,7 +660,6 @@ Version 0.27
 
 	$k->{add_loops} = 5; # errors
 
-
 =head1 DESCRIPTION
 
 C<Rope> is an Object Orientation system that is built on top of perls core hash tying implementation. It extends the functionality which is available with all the modern features you would expect from an modern OO system. This includes clear class and role definitions. With Rope you also get out of the box sorted objects, where the order you define persists.
@@ -938,6 +939,48 @@ Along with class definitions you can also generate object using Rope itself, the
 	$knot->{loops};
 	$with->loops;
 
+
+=head2 INITIALISE
+
+An before hook into new, the Rope META structure is passed as a param and can be validated and extended from within the sub routine.
+	
+	my $knot = Rope->new({
+		name => 'Knot',
+		properties => [
+			loops => 1,
+		],
+		INITIALISE => sub {
+			$_[1]->{properties}->{hitches} = {
+				type => Int,
+				value => 10,
+				initable => 0,
+				configurable => 0,
+			};
+			$_[1]->{properties}->{add_loops} => sub {
+				my ($self, $loop) = @_;
+				$self->{loops} += $loop;
+			};
+		}
+	});
+
+=head2 INITIALISED
+
+An after hook into new, the initialised Rope is passed as $self and can be validated and extended from within the sub routine.
+	
+	my $knot = Rope->new({
+		name => 'Knot',
+		properties => [
+			loops => 1,
+		],
+		INITIALISED => sub {
+			$_[0]->{hitches} = 10;
+			$_[0]->{add_loops} = sub {
+				my ($self, $loop) = @_;
+				$self->{loops} += $loop;
+			};
+		}
+	});
+
 =head2 destroy
 
 For objects that are running in a long process, like under a web server, you will want to explicitly call destroy on your objects as to achieve the correct scoping a reference has to be held in memory. If running under a script the problem will not exists as destruction happens when that script ends.
